#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hedgehog
version:              1.5
visibility:           public
id:                   hedgehog-1.5-EyJlwFbQiSs2nLetUKATII
key:                  hedgehog-1.5-EyJlwFbQiSs2nLetUKATII
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             https://hedgehog.qa
synopsis:             Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.

    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.

    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.

category:             Testing
abi:                  85a8c614684e43b144a3e957ceb121f4
exposed:              True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Barbie
    Hedgehog.Internal.Config Hedgehog.Internal.Discovery
    Hedgehog.Internal.Distributive Hedgehog.Internal.Exception
    Hedgehog.Internal.Gen Hedgehog.Internal.HTraversable
    Hedgehog.Internal.Opaque Hedgehog.Internal.Prelude
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hedgehog-1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hedgehog-1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hedgehog-1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog
hs-libraries:         HShedgehog-1.5-EyJlwFbQiSs2nLetUKATII
depends:
    ansi-terminal-1.1-FMAjddYCnoo35p0Ajg6Jk8
    async-2.2.6-1mBgL12wSAHIlTk64oC4Cy
    barbies-2.1.1.0-KvL9oyoqqGF8ezvvnNnRGG base-4.18.2.1
    bytestring-0.11.5.3
    concurrent-output-1.10.21-E3KCBAShi3r6p8O5lBEqfq containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5
    erf-2.0.0.0-4xz1P35HuR5Dy4ovZUgjCU exceptions-0.10.7
    lifted-async-0.11.0-8wtxlfFC0cW3FITLWb3KBX
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH
    monad-control-1.0.3.1-3NDl7WHMpP0FKNe71JSOVz mtl-2.3.1
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR
    primitive-0.9.1.0-4hlhnHtP0gACqmGq3bJZxL
    random-1.2.1.3-J8W47WuTchP2SADTtbNvax
    resourcet-1.3.0-xQkQK6AKd8CwOHTJH07Rv
    safe-exceptions-0.1.7.4-1VAvwwFmwsSFhjPPlpTl3V stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-K3Vss2loJKB8hKhKUfGlqH
    wl-pprint-annotated-0.1.0.1-B6pXOUI65qb5Z0M4endidj

haddock-interfaces:   /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

